import { AxiosResponse } from 'axios';
import { CreateNoteOptions, GetMe, GetUserHistory, GetUserNotes, GetUserNote, CreateUserNote, GetUserTeams, GetTeamNotes, CreateTeamNote, SingleNote } from './type';
export type RequestOptions = {
    unwrapData?: boolean;
};
type OptionReturnType<Opt, T> = Opt extends {
    unwrapData: false;
} ? AxiosResponse<T> : Opt extends {
    unwrapData: true;
} ? T : T;
export type APIClientOptions = {
    wrapResponseErrors: boolean;
};
export declare class API {
    readonly accessToken: string;
    hackmdAPIEndpointURL: string;
    options: APIClientOptions;
    private axios;
    constructor(accessToken: string, hackmdAPIEndpointURL?: string, options?: APIClientOptions);
    getMe<Opt extends RequestOptions>(options?: Opt): Promise<OptionReturnType<Opt, GetMe>>;
    getHistory<Opt extends RequestOptions>(options?: Opt): Promise<OptionReturnType<Opt, GetUserHistory>>;
    getNoteList<Opt extends RequestOptions>(options?: Opt): Promise<OptionReturnType<Opt, GetUserNotes>>;
    getNote<Opt extends RequestOptions>(noteId: string, options?: Opt): Promise<OptionReturnType<Opt, GetUserNote>>;
    createNote<Opt extends RequestOptions>(payload: CreateNoteOptions, options?: Opt): Promise<OptionReturnType<Opt, CreateUserNote>>;
    updateNoteContent<Opt extends RequestOptions>(noteId: string, content?: string, options?: Opt): Promise<OptionReturnType<Opt, SingleNote>>;
    updateNote<Opt extends RequestOptions>(noteId: string, payload: Partial<Pick<SingleNote, 'content' | 'readPermission' | 'writePermission' | 'permalink'>>, options?: Opt): Promise<OptionReturnType<Opt, SingleNote>>;
    deleteNote<Opt extends RequestOptions>(noteId: string, options?: Opt): Promise<OptionReturnType<Opt, SingleNote>>;
    getTeams<Opt extends RequestOptions>(options?: Opt): Promise<OptionReturnType<Opt, GetUserTeams>>;
    getTeamNotes<Opt extends RequestOptions>(teamPath: string, options?: Opt): Promise<OptionReturnType<Opt, GetTeamNotes>>;
    createTeamNote<Opt extends RequestOptions>(teamPath: string, payload: CreateNoteOptions, options?: Opt): Promise<OptionReturnType<Opt, CreateTeamNote>>;
    updateTeamNoteContent(teamPath: string, noteId: string, content?: string): Promise<AxiosResponse>;
    updateTeamNote(teamPath: string, noteId: string, options: Partial<Pick<SingleNote, 'content' | 'readPermission' | 'writePermission' | 'permalink'>>): Promise<AxiosResponse>;
    deleteTeamNote(teamPath: string, noteId: string): Promise<AxiosResponse>;
    private unwrapData;
}
export default API;
